@@ -18,9 +18,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifndef __CLUTTER_SCRIPT_PRIVATE_H__
@@ -103,7 +103,7 @@ gboolean clutter_script_parse_node        (ClutterScript *script,
 GType    clutter_script_get_type_from_symbol (const gchar *symbol);
 GType    clutter_script_get_type_from_class  (const gchar *name);
 
-gulong   clutter_script_resolve_animation_mode (const gchar *namer);
+gulong   clutter_script_resolve_animation_mode (JsonNode *node);
 
 gboolean clutter_script_enum_from_string  (GType          gtype,
                                            const gchar   *string,
