@@ -21,9 +21,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 /**
@@ -84,7 +84,7 @@ struct _ClutterShaderPrivate
   CoglHandle  fragment_shader;
 };
 
-enum 
+enum
 {
   PROP_0,
 
@@ -126,11 +126,11 @@ clutter_shader_set_property (GObject      *object,
   switch (prop_id)
     {
     case PROP_VERTEX_SOURCE:
-      clutter_shader_set_vertex_source (shader, 
+      clutter_shader_set_vertex_source (shader,
 					g_value_get_string (value), -1);
       break;
     case PROP_FRAGMENT_SOURCE:
-      clutter_shader_set_fragment_source (shader, 
+      clutter_shader_set_fragment_source (shader,
 					  g_value_get_string (value), -1);
       break;
     case PROP_ENABLED:
@@ -427,20 +427,19 @@ clutter_shader_glsl_bind (ClutterShader      *self,
                           GError            **error)
 {
   ClutterShaderPrivate *priv = self->priv;
-  GLint is_compiled = CGL_FALSE;
   CoglHandle shader = COGL_INVALID_HANDLE;
 
   switch (shader_type)
     {
     case CLUTTER_VERTEX_SHADER:
-      shader = cogl_create_shader (CGL_VERTEX_SHADER);
+      shader = cogl_create_shader (COGL_SHADER_TYPE_VERTEX);
       cogl_shader_source (shader, priv->vertex_source);
 
       priv->vertex_shader = shader;
       break;
 
     case CLUTTER_FRAGMENT_SHADER:
-      shader = cogl_create_shader (CGL_FRAGMENT_SHADER);
+      shader = cogl_create_shader (COGL_SHADER_TYPE_FRAGMENT);
       cogl_shader_source (shader, priv->fragment_source);
 
       priv->fragment_shader = shader;
@@ -450,22 +449,24 @@ clutter_shader_glsl_bind (ClutterShader      *self,
   g_assert (shader != COGL_INVALID_HANDLE);
 
   cogl_shader_compile (shader);
-  cogl_shader_get_parameteriv (shader,
-                               CGL_OBJECT_COMPILE_STATUS,
-                               &is_compiled);
-
-  if (is_compiled != CGL_TRUE)
+  if (!cogl_shader_is_compiled (shader))
     {
-      gchar error_buf[512];
+      gchar *log_buf;
 
-      cogl_shader_get_info_log (shader, 512, error_buf);
+      log_buf = cogl_shader_get_info_log (shader);
 
+      /* translators: the first %s is the type of the shader, either
+       * Vertex shader or Fragment shader; the second %s is the actual
+       * error as reported by COGL
+       */
       g_set_error (error, CLUTTER_SHADER_ERROR,
                    CLUTTER_SHADER_ERROR_COMPILE,
                    _("%s compilation failed: %s"),
                    shader_type == CLUTTER_VERTEX_SHADER ? _("Vertex shader")
                                                         : _("Fragment shader"),
-                   error_buf);
+                   log_buf);
+
+      g_free (log_buf);
 
       return FALSE;
     }
@@ -592,13 +593,13 @@ clutter_shader_release (ClutterShader *shader)
   g_assert (priv->program != COGL_INVALID_HANDLE);
 
   if (priv->vertex_is_glsl && priv->vertex_shader != COGL_INVALID_HANDLE)
-    cogl_shader_unref (priv->vertex_shader);
+    cogl_handle_unref (priv->vertex_shader);
 
   if (priv->fragment_is_glsl && priv->fragment_shader != COGL_INVALID_HANDLE)
-    cogl_shader_unref (priv->fragment_shader);
+    cogl_handle_unref (priv->fragment_shader);
 
   if (priv->program != COGL_INVALID_HANDLE)
-    cogl_program_unref (priv->program);
+    cogl_handle_unref (priv->program);
 
   priv->vertex_shader = COGL_INVALID_HANDLE;
   priv->fragment_shader = COGL_INVALID_HANDLE;
@@ -695,31 +696,6 @@ clutter_shader_get_is_enabled (ClutterShader *shader)
   return shader->priv->is_enabled;
 }
 
-/**
- * clutter_shader_set_uniform_1f:
- * @shader: a #ClutterShader
- * @name: name of uniform in vertex or fragment program to set.
- * @value: the new value of the uniform.
- *
- * Sets a user configurable variable in the shader programs attached
- * to a #ClutterShader.
- *
- * Since: 0.6
- *
- * Deprecated: 1.0: Use clutter_shader_set_uniform() instead
- */
-void
-clutter_shader_set_uniform_1f (ClutterShader *shader,
-                               const gchar   *name,
-                               gfloat         value)
-{
-  GValue real_value = { 0, };
-
-  g_value_init (&real_value, G_TYPE_FLOAT);
-  clutter_shader_set_uniform (shader, name, &real_value);
-  g_value_unset (&real_value);
-}
-
 /**
  * clutter_shader_set_uniform:
  * @shader: a #ClutterShader.
@@ -764,7 +740,7 @@ clutter_shader_set_uniform (ClutterShader *shader,
     }
   else if (CLUTTER_VALUE_HOLDS_SHADER_INT (value))
     {
-      const COGLint *ints;
+      const int *ints;
 
       ints = clutter_value_get_shader_int (value, &size);
       cogl_program_uniform_int (location, size, 1, ints);
@@ -784,7 +760,7 @@ clutter_shader_set_uniform (ClutterShader *shader,
     }
   else if (G_VALUE_HOLDS_INT (value))
     {
-      COGLint int_val = g_value_get_int (value);
+      int int_val = g_value_get_int (value);
 
       cogl_program_uniform_int (location, 1, 1, &int_val);
     }
