@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -46,7 +46,7 @@ static gboolean
 cogl_create_context (void)
 {
   GLubyte default_texture_data[] = { 0xff, 0xff, 0xff, 0x0 };
-  gulong  enable_flags = 0;
+  unsigned long  enable_flags = 0;
   CoglHandle window_buffer;
 
   if (_context != NULL)
@@ -152,6 +152,8 @@ cogl_create_context (void)
 
   _context->current_pbo = NULL;
 
+  _context->max_texture_units = -1;
+
   return TRUE;
 }
 
