@@ -16,9 +16,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -78,6 +78,7 @@ cogl_handle_unref (CoglHandle handle)
   CoglHandleObject *obj = (CoglHandleObject *)handle;
 
   g_return_if_fail (handle != COGL_INVALID_HANDLE);
+  g_return_if_fail (obj->ref_count > 0);
 
   if (--obj->ref_count < 1)
     {
