@@ -215,6 +215,7 @@ clutter_backend_glx_get_features (ClutterBackend *backend)
 {
   ClutterBackendGLX *backend_glx = CLUTTER_BACKEND_GLX (backend);
   const gchar *glx_extensions = NULL;
+  const gchar *gl_extensions = NULL;
   ClutterFeatureFlags flags;
   gboolean use_dri = FALSE;
 
@@ -242,6 +243,26 @@ clutter_backend_glx_get_features (ClutterBackend *backend)
 
   CLUTTER_NOTE (BACKEND, "  GLX Extensions: %s", glx_extensions);
 
+  gl_extensions = (const gchar *)glGetString (GL_EXTENSIONS);
+
+  /* When using glBlitFramebuffer or glXCopySubBufferMESA for sub stage
+   * redraws, we cannot rely on glXSwapIntervalSGI to throttle the blits
+   * so we need to resort to manually synchronizing with the vblank so we
+   * always check for the video_sync extension...
+   */
+  if (_cogl_check_extension ("GLX_SGI_video_sync", glx_extensions) &&
+      /* Note: the GLX_SGI_video_sync spec explicitly states this extension
+       * only works for direct contexts. */
+      glXIsDirect (clutter_x11_get_default_display (),
+                   backend_glx->gl_context))
+    {
+      backend_glx->get_video_sync =
+        (GetVideoSyncProc) cogl_get_proc_address ("glXGetVideoSyncSGI");
+
+      backend_glx->wait_video_sync =
+        (WaitVideoSyncProc) cogl_get_proc_address ("glXWaitVideoSyncSGI");
+    }
+
   use_dri = check_vblank_env ("dri");
 
   /* First check for explicit disabling or it set elsewhere (eg NVIDIA) */
@@ -312,12 +333,6 @@ clutter_backend_glx_get_features (ClutterBackend *backend)
     {
       CLUTTER_NOTE (BACKEND, "attempting glXGetVideoSyncSGI vblank setup");
 
-      backend_glx->get_video_sync =
-        (GetVideoSyncProc) cogl_get_proc_address ("glXGetVideoSyncSGI");
-
-      backend_glx->wait_video_sync =
-        (WaitVideoSyncProc) cogl_get_proc_address ("glXWaitVideoSyncSGI");
-
       if ((backend_glx->get_video_sync != NULL) &&
           (backend_glx->wait_video_sync != NULL))
         {
@@ -363,6 +378,17 @@ vblank_setup_done:
     {
       backend_glx->copy_sub_buffer =
         (CopySubBufferProc) cogl_get_proc_address ("glXCopySubBufferMESA");
+      backend_glx->can_blit_sub_buffer = TRUE;
+      backend_glx->blit_sub_buffer_is_synchronized = TRUE;
+    }
+  else if (_cogl_check_extension ("GL_EXT_framebuffer_blit", gl_extensions))
+    {
+      CLUTTER_NOTE (BACKEND,
+                    "Using glBlitFramebuffer fallback for sub_buffer copies");
+      backend_glx->blit_framebuffer =
+        (BlitFramebufferProc) cogl_get_proc_address ("glBlitFramebuffer");
+      backend_glx->can_blit_sub_buffer = TRUE;
+      backend_glx->blit_sub_buffer_is_synchronized = FALSE;
     }
 
   CLUTTER_NOTE (BACKEND, "backend features checked");
@@ -464,6 +490,29 @@ _clutter_backend_glx_get_fbconfig (ClutterBackendGLX *backend_glx,
     return FALSE;
 }
 
+void
+_clutter_backend_glx_blit_sub_buffer (ClutterBackendGLX *backend_glx,
+                                      GLXDrawable drawable,
+                                      int x, int y, int width, int height)
+{
+  ClutterBackendX11 *backend_x11 = CLUTTER_BACKEND_X11 (backend_glx);
+
+  if (backend_glx->copy_sub_buffer)
+    {
+      backend_glx->copy_sub_buffer (backend_x11->xdpy, drawable,
+                                    x, y, width, height);
+    }
+  else if (backend_glx->blit_framebuffer)
+    {
+      glDrawBuffer (GL_FRONT);
+      backend_glx->blit_framebuffer (x, y, x + width, y + height,
+                                     x, y, x + width, y + height,
+                                     GL_COLOR_BUFFER_BIT, GL_NEAREST);
+      glDrawBuffer (GL_BACK);
+      glFlush();
+    }
+}
+
 static XVisualInfo *
 clutter_backend_glx_get_visual_info (ClutterBackendX11 *backend_x11)
 {
@@ -555,6 +604,7 @@ clutter_backend_glx_create_context (ClutterBackend  *backend,
                                     root_xwin,
                                     xvisinfo->visual,
                                     AllocNone);
+  attrs.border_pixel = 0;
 
   backend_glx->dummy_xwin = XCreateWindow (xdisplay, root_xwin,
                                            -100, -100, 1, 1,
@@ -562,7 +612,7 @@ clutter_backend_glx_create_context (ClutterBackend  *backend,
                                            xvisinfo->depth,
                                            CopyFromParent,
                                            xvisinfo->visual,
-                                           CWOverrideRedirect | CWColormap,
+                                           CWOverrideRedirect | CWColormap | CWBorderPixel,
                                            &attrs);
 
   /* Try and create a GLXWindow to use with extensions dependent on
@@ -691,6 +741,12 @@ clutter_backend_glx_ensure_context (ClutterBackend *backend,
                                  drawable,
                                  drawable,
                                  backend_glx->gl_context);
+          /*
+           * In case we are using GLX_SGI_swap_control for vblank syncing we need call
+           * glXSwapIntervalSGI here to make sure that it affects the current drawable.
+           */
+          if (backend_glx->vblank_type == CLUTTER_VBLANK_GLX_SWAP && backend_glx->swap_interval != NULL)
+            backend_glx->swap_interval (1);
         }
 
       if (clutter_x11_untrap_x_errors ())
